@@ -52,6 +52,7 @@ class BackupSet:
         self.start_time = None                      # will be set if inc
         self.end_time = None                        # will be set if inc
         self.partial = False                        # true if a partial backup
+        self.encrypted = False                      # true if an encrypted backup
 
     def is_complete(self):
         """
@@ -108,6 +109,7 @@ class BackupSet:
         self.end_time = pr.end_time
         self.time = pr.time
         self.partial = pr.partial
+        self.encrypted = bool(pr.encrypted)
         self.info_set = True
 
     def set_manifest(self, remote_filename):
@@ -137,7 +139,7 @@ class BackupSet:
         rfn.reverse()
         try:
             self.backend.delete(rfn)
-        except:
+        except Exception:
             log.Debug("BackupSet.delete: missing %s" % rfn)
             pass
         for lfn in globals.archive_dir.listdir():
@@ -145,10 +147,15 @@ class BackupSet:
             if (pr
                 and pr.time == self.time
                 and pr.start_time == self.start_time
-                and pr.end_time == self.end_time):
+                and pr.end_time == self.end_time
+                and pr.type != "new-sig" ):
+                # do not remove new sigs from the cache:
+                # they aren't removed from the remote archive,
+                # and subsequent backups will have to resync
+                # which is bad if running non-interactive with encrypt-key
                 try:
                     globals.archive_dir.append(lfn).delete()
-                except:
+                except Exception:
                     log.Debug("BackupSet.delete: missing %s" % lfn)
                     pass
 
@@ -240,9 +247,14 @@ class BackupSet:
         volume_filenames = map(lambda x: self.volume_name_dict[x],
                                volume_num_list)
         if self.remote_manifest_name:
-            return [self.remote_manifest_name] + volume_filenames
-        else:
-            return volume_filenames
+            # For convenience of implementation for restart support, we treat
+            # local partial manifests as this set's remote manifest.  But
+            # when specifically asked for a list of remote filenames, we
+            # should not include it.
+            pr = file_naming.parse(self.remote_manifest_name)
+            if not pr or not pr.partial:
+                volume_filenames.append(self.remote_manifest_name)
+        return volume_filenames
 
     def get_time(self):
         """
@@ -361,7 +373,8 @@ class BackupChain:
             else:
                 type = "inc"
                 time = s.end_time
-            l.append("%s%s %s %d" % (prefix, type, dup_time.timetostring(time), (len(s)),))
+            enc = "enc" if s.encrypted else "noenc"
+            l.append("%s%s %s %d %s" % (prefix, type, dup_time.timetostring(time), (len(s)), enc))
         return l
 
     def __str__(self):
@@ -912,11 +925,9 @@ class CollectionsStatus:
             else:
                 assert len(chain_list) == 2
                 if chain_list[0].backend: # is remote, goes first
-                    assert chain_list[1].archive_dir # other is local
                     sorted_chain_list.append(chain_list[0])
                     sorted_chain_list.append(chain_list[1])
                 else: # is local, goes second
-                    assert chain_list[1].backend # other is remote
                     sorted_chain_list.append(chain_list[1])
                     sorted_chain_list.append(chain_list[0])
 
@@ -991,7 +1002,7 @@ class CollectionsStatus:
             if self.matched_chain_pair:
                 matched_sig_chain = self.matched_chain_pair[0]
                 for sig_chain in self.all_sig_chains:
-                    print sig_chain.start_time, matched_sig_chain.start_time, 
+                    print sig_chain.start_time, matched_sig_chain.start_time,
                     print sig_chain.end_time, matched_sig_chain.end_time
                     if (sig_chain.start_time == matched_sig_chain.start_time and
                         sig_chain.end_time == matched_sig_chain.end_time):
@@ -1076,7 +1087,7 @@ class CollectionsStatus:
         Furthermore, none of the times will be of a set which a newer
         set may depend on.  For instance, if set A is a full set older
         than t, and set B is an incremental based on A which is newer
-        than tt, then the time of set A will not be returned.
+        than t, then the time of set A will not be returned.
         """
         old_sets = []
         for chain in self.get_chains_older_than(t):
